INI Files — Translate Toolkit 1.13.0-rc1 documentation

# INI Files

Also know as initialisation files. These are in some cases used to store translations.

## Conformance

The toolkit uses iniparse, an INI file parser that preserves layout and follows the .ini format as supported by the Python language.

### Dialects

The format supports two dialects:

- default: standard iniparse handling of INI files
- inno: follows Inno escaping conventions

## References

Further information is available on .ini files:

- Wikipedia INI file format article
- Unofficial specification